# easybioinfo
Convenient python functions for bioinformatics

Install with conda:

``conda install -c mmariotti easybioinfo``

Or alternatively with pip:

``pip install easybioinfo``

See documentation at https://easybioinfo.readthedocs.io/
